# LETSQL

Create a connection object:

```{.python}
import letsql as ls

con = ls.connect()  # <1>
```

1. Adjust connection parameters as needed.

### Connection Parameters

```{python}
#| echo: false
#| output: asis
from _utils import render_do_connect

render_do_connect()
```

{{< include ./_templates/api.qmd >}}
